Experiment Imports — Map of Objects

Skip to main content
`Ctrl`+`K`

# Experiment Imports

add_coordinates_to_experiment(experiment, dim: int = 2, file_name: str | None = None) → dict

  Imports from a file precomputed coordinates of all the points, where each point refer to one instance

  Parameters:

    - experiment (Experiment) – Experiment object.

    - dim (int) – Dimension.

    - file_name (str) – Name of file in which the coordinates are stored.

  Returns:

    Coordinates.

  Return type:

    dict

add_distances_to_experiment(experiment) -> (<class 'dict'>, <class 'dict'>, <class 'dict'>, <class 'dict'>)

  Imports precomputed distances between each pair of instances from a file while preparing an experiment

  Parameters:

    experiment (Experiment) – Experiment object.

  Returns:

    distances, times, stds, mappings

  Return type:

    (dict, dict, dict, dict)

get_values_from_csv_file(experiment, feature_id, feature_long_id=None, upper_limit=inf, lower_limit=-inf, column_id='value') → dict

  Imports values for a feature_id from a .csv file

  Parameters:

    experiment (Experiment) – Experiment object.

  Returns:

    Feature dictionary.

  Return type:

    dict

import_distances_from_file(experiment, distance_id) → dict

  Imports distances between each pair of instances from a file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - distance_id (str) – Name of the distance.

  Returns:

    Distances.

  Return type:

    dict